On 09.06.2013 16:16, Aleksander Morgado wrote:
> Hey Poma,
>
> On 08/06/13 09:02, poma wrote:
>> OK, that can be overcome via 'ID_MM_DEVICE_IGNORE' within a custom rule.
>> As for this device,
>> http://www.koutech.com/proddetail.asp?linenumber=56[1]
>> 'ID_MM_DEVICE_IGNORE' *must* be applied, if we want to prevent scanning
>> connected ups and nut-driver/server breakage.
>> And all this as a result of
>> /lib/udev/rules.d/80-mm-candidate.rules
>> SUBSYSTEM=="tty", ENV{ID_MM_CANDIDATE}="1"
>> Therefore 'ID_MM_PLATFORM_DRIVER_PROBE' is redundant, in the first
>> place, in this case.
>>
>> mmcli --version
>> mmcli 0.7.991
>>
>>
>> poma
>>
>>
>> [1]
>> DEVPATH=/class/pci_bus/0000:01/device/0000:01:06.0
>> DRIVER=serial
>> ID_MODEL_FROM_DATABASE=1P2S
>> ID_PCI_CLASS_FROM_DATABASE=Communication controller
>> ID_PCI_SUBCLASS_FROM_DATABASE=Communication controller
>> ID_VENDOR_FROM_DATABASE=MosChip Semiconductor Technology Ltd.
>> MODALIAS=pci:v00009710d00009835sv00001000sd00000012bc07sc80i02
>> PCI_CLASS=78002
>> PCI_ID=9710:9835
>> PCI_SLOT_NAME=0000:01:06.0
>> PCI_SUBSYS_ID=1000:0012
>> SUBSYSTEM=pci
>
> I don't think we should probe devices in the 'pci' subsystem unless
> whitelisted with ID_MM_PLATFORM_DRIVER_PROBE. Can you grab this patch,
> replace 'pnp' with 'pci' and retest?
>
> https://mail.gnome.org/archives/networkmanager-list/2013-June/txtfYzWozQRdF.txt
OK passed, plus we got a free scan prevention for NICs[1]. :)
poma
<resolved>
[1]
Couldn't find support for device at '/sys/devices/pci…': not supported
by any plugin
[PCI<->RS232<->UPS/56k]
Could not grab port (tty/ttyS0): 'Cannot add port 'tty/ttyS0', unhandled
serial type'
Couldn't create modem for device at '/sys/devices/pci…': Failed to find
primary AT port
</resolved>
diff --git a/src/mm-manager.c b/src/mm-manager.c
index 69134e1..8b03569 100644
--- a/src/mm-manager.c
+++ b/src/mm-manager.c
@@ -285,10 +285,12 @@ device_added (MMManager *manager,
goto out;
}
/* If the physdev is a 'platform' device that's not whitelisted, ignore it */
physdev_subsys = g_udev_device_get_subsystem (physdev);
if ( physdev_subsys
- && !strcmp (physdev_subsys, "platform")
+ && ( g_str_equal (physdev_subsys, "platform")
+ || g_str_equal (physdev_subsys, "pnp")
+ || g_str_equal (physdev_subsys, "pci"))
&& !g_udev_device_get_property_as_boolean (physdev, "ID_MM_PLATFORM_DRIVER_PROBE")) {
mm_dbg ("(%s/%s): port's parent platform driver is not whitelisted", subsys, name);
goto out;
@@ -285,10 +285,12 @@ device_added (MMManager *manager,
goto out;
}
- /* If the physdev is a 'platform' device that's not whitelisted, ignore it */
+ /* If the physdev is a 'platform', 'pnp', or 'pci' device that's not whitelisted, ignore it */
physdev_subsys = g_udev_device_get_subsystem (physdev);
if ( physdev_subsys
_______________________________________________
networkmanager-list mailing list
[email protected]
https://mail.gnome.org/mailman/listinfo/networkmanager-list